@@ -367,6 +367,8 @@ def make_mr_slots(config, model_slots):
         platforms=config['platforms'],
         merge=config['merge'],
         model_slots=model_slots)
+    # register trigger information in test_slot
+    test_slot.metadata['ci_test']['trigger'] = config['trigger']
     return [ref_slot, test_slot]
 
 
